<div align="center">
  <a href="https://lightningrobot.github.io/" target="_blank">
    <img width="160" src="https://lightningrobot.github.io/logo.png" alt="logo">
  </a>
  <h1 id="koishi"><a href="https://lightningrobot.github.io/" target="_blank">闪电机器人</a></h1>

</div>

## 介绍

LightningRobot 是一个跨平台、可扩展、高性能的聊天机器人框架。

它的图标来源于“闪电”Emoji，简单易懂，这个名字也包含着框架允许快如闪电的寓意。

## 使用
- [快速起步](https://lightningrobot.github.io/)
- [插件开发](https://lightningrobot.github.io/dev/)

## 关于
闪电机器人完全使用 [MIT](./LICENSE) 协议开源，每个人都应维护良好的开源生态。

Copyright © 2023-2024, Zhihan